@@ -15,6 +15,7 @@ from bauh.gems.flatpak import EXPORTS_PATH, VERSION_1_3, VERSION_1_2, VERSION_1_
 
 RE_SEVERAL_SPACES = re.compile(r'\s+')
 RE_COMMIT = re.compile(r'(Latest commit|Commit)\s*:\s*(.+)')
+OPERATION_UPDATE_SYMBOLS = {'i', 'u'}
 
 
 def get_app_info_fields(app_id: str, branch: str, installation: str, fields: List[str] = [], check_runtime: bool = False):
@@ -93,7 +94,7 @@ def get_commit(app_id: str, branch: str, installation: str) -> Optional[str]:
 def list_installed(version: Version) -> List[dict]:
     apps = []
 
-    if version < VERSION_1_3:
+    if version < VERSION_1_2:
         app_list = new_subprocess(['flatpak', 'list', '-d'])
 
         for o in app_list.stdout:
@@ -208,12 +209,14 @@ def read_updates(version: Version, installation: str) -> Dict[str, set]:
 
                     if len(line_split) > 2:
                         if version >= VERSION_1_5:
-                            update_id = '{}/{}/{}'.format(line_split[2], line_split[3], installation)
+                            update_id = f'{line_split[2]}/{line_split[3]}/{installation}/{line_split[5]}'
+                        elif version >= VERSION_1_2:
+                            update_id = f'{line_split[2]}/{line_split[4]}/{installation}/{line_split[5]}'
                         else:
                             update_id = '{}/{}/{}'.format(line_split[2], line_split[4], installation)
 
-                        if len(line_split) >= 6:
-                            if line_split[4] != 'i':
+                        if version >= VERSION_1_3 and len(line_split) >= 6:
+                            if line_split[4].strip().lower() in OPERATION_UPDATE_SYMBOLS:
                                 if '(partial)' in line_split[-1]:
                                     res['partial'].add(update_id)
                                 else:
@@ -396,10 +399,10 @@ def run(app_id: str):
 
 def map_update_download_size(app_ids: Iterable[str], installation: str, version: Version) -> Dict[str, int]:
     success, output = ProcessHandler().handle_simple(SimpleProcess(['flatpak', 'update', '--{}'.format(installation)]))
-    if version >= VERSION_1_5:
+    if version >= VERSION_1_2:
         res = {}
         p = re.compile(r'^\d+.\t')
-        p2 = re.compile(r'\s([0-9.?a-zA-Z]+)\s?')
+        p2 = re.compile(r'([0-9.?a-zA-Z]+\s?)')
         for l in output.split('\n'):
             if l:
                 line = l.strip()
@@ -417,11 +420,17 @@ def map_update_download_size(app_ids: Iterable[str], installation: str, version:
                             size_tuple = p2.findall(line_split[6])
 
                             if size_tuple:
-                                size = size_tuple[0].split('?')
+                                if version >= VERSION_1_5:
+                                    size = size_tuple[0].split('?')
 
-                                if size and len(size) > 1:
+                                    if size and len(size) > 1:
+                                        try:
+                                            res[related_id[0].strip()] = size_to_byte(float(size[0]), size[1].strip())
+                                        except:
+                                            traceback.print_exc()
+                                else:
                                     try:
-                                        res[related_id[0].strip()] = size_to_byte(float(size[0]), size[1])
+                                        res[related_id[0].strip()] = size_to_byte(float(size_tuple[0]), size_tuple[1].strip())
                                     except:
                                         traceback.print_exc()
         return res
