@@ -11,14 +11,14 @@ from PyQt5.QtWidgets import QWidget, QVBoxLayout, QCheckBox, QHeaderView, QToolB
     QLabel, QPlainTextEdit, QProgressBar, QPushButton, QComboBox, QApplication, QListView, QSizePolicy, \
     QMenu, QHBoxLayout
 
-from bauh import LOGS_PATH
+from bauh.api import user
 from bauh.api.abstract.cache import MemoryCache
 from bauh.api.abstract.context import ApplicationContext
 from bauh.api.abstract.controller import SoftwareManager, SoftwareAction
 from bauh.api.abstract.model import SoftwarePackage
 from bauh.api.abstract.view import MessageType
 from bauh.api.http import HttpClient
-from bauh.commons import user
+from bauh.api.paths import LOGS_DIR
 from bauh.commons.html import bold
 from bauh.context import set_theme
 from bauh.stylesheet import read_all_themes_metadata, ThemeMetadata
@@ -373,7 +373,7 @@ class ManageWindow(QWidget):
         self.container_bottom.layout().addWidget(bt_themes)
         self.comp_manager.register_component(BT_THEMES, bt_themes)
 
-        self.custom_actions = manager.get_custom_actions()
+        self.custom_actions = [a for a in manager.gen_custom_actions()]
         bt_custom_actions = IconButton(action=self.show_custom_actions,
                                        i18n=self.i18n,
                                        tooltip=self.i18n['manage_window.bt_custom_actions.tip'])
@@ -460,7 +460,7 @@ class ManageWindow(QWidget):
         self.comp_manager.register_group(GROUP_LOWER_BTS, False, BT_SUGGESTIONS, BT_THEMES, BT_CUSTOM_ACTIONS, BT_SETTINGS, BT_ABOUT)
 
     def update_custom_actions(self):
-        self.custom_actions = self.manager.get_custom_actions()
+        self.custom_actions = [a for a in self.manager.gen_custom_actions()]
 
     def _update_process_progress(self, val: int):
         if self.progress_controll_enabled:
@@ -1076,7 +1076,7 @@ class ManageWindow(QWidget):
         new_width *= 1.05  # this extra size is not because of the toolbar button, but the table upgrade buttons
 
         if (self.pkgs and accept_lower_width) or new_width > self.width():
-            self.resize(new_width, self.height())
+            self.resize(int(new_width), self.height())
 
     def set_progress_controll(self, enabled: bool):
         self.progress_controll_enabled = enabled
@@ -1106,8 +1106,8 @@ class ManageWindow(QWidget):
 
             if output:
                 try:
-                    Path(UpgradeSelected.LOGS_DIR).mkdir(parents=True, exist_ok=True)
-                    logs_path = '{}/{}.log'.format(UpgradeSelected.LOGS_DIR, res['id'])
+                    Path(UpgradeSelected.UPGRADE_LOGS_DIR).mkdir(parents=True, exist_ok=True)
+                    logs_path = '{}/{}.log'.format(UpgradeSelected.UPGRADE_LOGS_DIR, res['id'])
                     with open(logs_path, 'w+') as f:
                         f.write(output)
 
@@ -1339,11 +1339,12 @@ class ManageWindow(QWidget):
         console_output = self.textarea_details.toPlainText()
 
         if console_output:
-            log_path = '{}/install/{}/{}'.format(LOGS_PATH, res['pkg'].model.get_type(), res['pkg'].model.name)
+            log_path = f"{LOGS_DIR}/install/{res['pkg'].model.get_type()}/{res['pkg'].model.name}"
             try:
                 Path(log_path).mkdir(parents=True, exist_ok=True)
 
-                log_file = log_path + '/{}.log'.format(int(time.time()))
+                log_file = f'{log_path}/{int(time.time())}.log'
+
                 with open(log_file, 'w+') as f:
                     f.write(console_output)
 
@@ -1421,10 +1422,11 @@ class ManageWindow(QWidget):
         self.progress_bar.setValue(value)
 
     def begin_execute_custom_action(self, pkg: Optional[PackageView], action: CustomSoftwareAction):
-        if pkg is None and not ConfirmationDialog(title=self.i18n['confirmation'].capitalize(),
-                                                  body='<p>{}</p>'.format(self.i18n['custom_action.proceed_with'].capitalize().format(bold(self.i18n[action.i18n_label_key]))),
-                                                  icon=QIcon(action.icon_path) if action.icon_path else QIcon(resource.get_path('img/logo.svg')),
-                                                  i18n=self.i18n).ask():
+        if pkg is None and action.requires_confirmation and \
+                not ConfirmationDialog(title=self.i18n['confirmation'].capitalize(),
+                                       body='<p>{}</p>'.format(self.i18n['custom_action.proceed_with'].capitalize().format(bold(self.i18n[action.i18n_label_key]))),
+                                       icon=QIcon(action.icon_path) if action.icon_path else QIcon(resource.get_path('img/logo.svg')),
+                                       i18n=self.i18n).ask():
             return False
 
         pwd = None
